@@ -11,8 +11,8 @@ def _get_path_default():
     _path_default = []
 
     if config.paths.project_home:
-        _path_default.append(os.path.join(config.paths.project_home, ".bin"))
-        _path_default.append(os.path.join(config.paths.project_home, "bin"))
+        _path_default.append(".bin")
+        _path_default.append("bin")
 
     if config.paths.home:
         _path_default.append(os.path.join(config.paths.home, ".bin"))
@@ -38,7 +38,7 @@ class ShellSchema(FeatureSchema):
     shell = fields.String(required=True)
     path = fields.Nested(PathSchema, required=True, default=PathSchema())
     envignore = fields.List(fields.String(), required=False, default=[
-        "PYENV_*", "_", "PS1", "PS2", "PS3", "PS4"
+        "PYENV_*", "_", "PS1", "PS2", "PS3", "PS4", "PWD"
     ])
     aliases = fields.Dict(required=False, default={})
     global_aliases = fields.List(fields.String(), required=False, default=[])
