@@ -52,12 +52,20 @@ class TraefikFeature(Feature):
             if os.path.exists(config_directory):
                 feature_config['config_directory'] = config_directory
 
+            config_directory = os.path.join(config.paths.home, 'docker-toolbox', '.docker', 'traefik', 'hosts')
+            if os.path.exists(config_directory):
+                feature_config['config_directory'] = config_directory
+
         extra_services = feature_config.get('extra_services')
         if extra_services:
             for extra_service in extra_services.values():
+                domain = extra_service.get('domain')
                 if not extra_service.get('rule'):
-                    extra_service['rule'] = "Host(`%s`)" % extra_service.get('domain')
-                if extra_service.get('https') is not False and not extra_service.get('domain'):
+                    if not domain:
+                        raise FeatureConfigurationAutoConfigureError(self, 'extra_services',
+                                                                     "domain must be defined when rule is not defined.")
+                    extra_service['rule'] = "Host(`%s`)" % domain
+                if extra_service.get('https') is not False and not domain:
                     raise FeatureConfigurationAutoConfigureError(self, 'extra_services',
                                                                  "domain must be defined when https is not False.")
 
