@@ -18,7 +18,7 @@ class TestFilesGenerated:
         assert not os.path.exists("test.dev.yml.jinja")
         with open("test.dev.yml.jsonnet", "r") as dockerfile:
             data = dockerfile.read()
-            assert data == '{["e" + "n" + "v"]: "dev"}'
+            assert data == '{["e" + "n" + "v"]: "dev"}\n'
 
         assert os.path.exists("test.dev.yml")
         with open("test.dev.yml", "r") as dockerfile:
@@ -33,7 +33,7 @@ class TestFilesGenerated:
         assert os.path.islink("test.yml")
 
         assert os.path.exists(".gitignore")
-        assert expect_gitignore('.gitignore', 'test.dev.yml.jsonnet', 'test.dev.yml', 'test.yml')
+        assert expect_gitignore('.gitignore', '/test.dev.yml.jsonnet', '/test.dev.yml', '/test.yml')
 
     def test_ensure_chaining_with_custom_dependencies(self, project_loader):
         project_loader("ensure-chaining-with-custom-dependencies")
@@ -61,7 +61,7 @@ class TestFilesGenerated:
         assert os.path.islink("test.yml")
 
         assert os.path.exists(".gitignore")
-        assert expect_gitignore('.gitignore', 'test.dev.yml.jinja', 'test.dev.yml', 'test.yml')
+        assert expect_gitignore('.gitignore', '/test.dev.yml.jinja', '/test.dev.yml', '/test.yml')
 
     def test_directories_overriden(self, project_loader):
         project_loader("directories-overriden")
